@@ -10,7 +10,7 @@ import argparse
 import sightcall_auth.parse_p12 as parse_p12
 import sightcall_auth.config as config
 
-__all__ = ['']
+__all__ = ['extract']
 
 parser = argparse.ArgumentParser(description='Extract a p12 file.')
 parser.add_argument(
@@ -23,7 +23,7 @@ parser.add_argument(
     'passphrase', type=str, help='The passphrase of the p12 file.')
 args = parser.parse_args()
 
-passphrase = args.passphrase.encode(encoding='UTF-8')
 
 
-parse_p12(args.p12_path, passphrase, config.directory)
+def extract():
+    parse_p12(args.p12_path, args.passphrase, config.directory)
\ No newline at end of file
