@@ -62,8 +62,8 @@ class Auth():
 
     def connect(self, uid):
         https_con = HTTPSClientAuthHandler(
-            path.join(self.directory, '/private_key.pem'),
-            path.join(self.directory, '/cert.pem')
+            path.join(self.directory, 'private_key.pem'),
+            path.join(self.directory, 'cert.pem')
         )
         opener = request.build_opener(https_con)
         url_params = "?client_id={0}&client_secret={1}&uid={2}"\
